<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en_US">
<context>
    <name>S:</name>
    <message>
        <location filename="customtype.cpp" line="93"/>
        <source></source>
        <comment>the device ID of the current device, e.g. &quot;battery0&quot;</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <source>help</source>
        <translation type="vanished">帮助</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="vanished">关闭</translation>
    </message>
    <message>
        <location filename="titlewidget.cpp" line="79"/>
        <source>Power Information</source>
        <oldsource>Power Statistics-device information</oldsource>
        <translation>电源统计-设备信息</translation>
    </message>
</context>
<context>
    <name>UkpmWidget</name>
    <message>
        <location filename="ukpm-widget.cpp" line="201"/>
        <location filename="ukpm-widget.cpp" line="307"/>
        <location filename="ukpm-widget.cpp" line="1928"/>
        <source>Charging</source>
        <translation>正充电</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="204"/>
        <location filename="ukpm-widget.cpp" line="310"/>
        <location filename="ukpm-widget.cpp" line="1931"/>
        <source>Discharging</source>
        <translation>正放电</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="207"/>
        <location filename="ukpm-widget.cpp" line="313"/>
        <location filename="ukpm-widget.cpp" line="1934"/>
        <source>Empty</source>
        <translation>空</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="210"/>
        <location filename="ukpm-widget.cpp" line="316"/>
        <location filename="ukpm-widget.cpp" line="1937"/>
        <source>Charged</source>
        <translation>已充满</translation>
    </message>
    <message>
        <source>Notebook battery</source>
        <translation type="vanished">笔记本电池</translation>
    </message>
    <message>
        <source>other</source>
        <translation type="vanished">未知</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">是</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">不</translation>
    </message>
    <message>
        <source> s</source>
        <translation type="vanished">秒</translation>
    </message>
    <message>
        <source> m</source>
        <translation type="vanished">分钟</translation>
    </message>
    <message>
        <source> h</source>
        <translation type="vanished">小时</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="103"/>
        <source>AC adapter</source>
        <translation>交流电源适配器</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="107"/>
        <source>Laptop battery</source>
        <translation>笔记本电池</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="111"/>
        <source>UPS</source>
        <translation>UPS</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="115"/>
        <source>Monitor</source>
        <translation>Monitor</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="119"/>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="123"/>
        <source>Keyboard</source>
        <translation>Keyboard</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="127"/>
        <source>PDA</source>
        <translation>PDA</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="131"/>
        <source>Cell phone</source>
        <translation>Cell phone</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="135"/>
        <source>Media player</source>
        <translation>Media player</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="139"/>
        <source>Tablet</source>
        <translation>Tablet</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="143"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Detail</source>
        <translation type="vanished">详细</translation>
    </message>
    <message>
        <source>attribute</source>
        <translation type="vanished">属性</translation>
    </message>
    <message>
        <source>value</source>
        <translation type="vanished">值</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="416"/>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="418"/>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>PowerSupply</source>
        <translation type="vanished">电源</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="503"/>
        <source>Online</source>
        <translation>在线</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="421"/>
        <source>Vendor</source>
        <translation>生产商</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="423"/>
        <source>Model</source>
        <translation>型号</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="vanished">刷新</translation>
    </message>
    <message>
        <source>IsPresent</source>
        <translation type="vanished">存在</translation>
    </message>
    <message>
        <source>IsRechargeable</source>
        <translation type="vanished">可充电</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="457"/>
        <source>State</source>
        <translation>状态</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="462"/>
        <source>Energy</source>
        <translation>能量</translation>
    </message>
    <message>
        <source>EnergyFull</source>
        <translation type="vanished">满时能量</translation>
    </message>
    <message>
        <source>EnergyFullDesign</source>
        <translation type="vanished">设计满时能量</translation>
    </message>
    <message>
        <source>EnergyRate</source>
        <translation type="vanished">功率</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="476"/>
        <source>Voltage</source>
        <translation>电压</translation>
    </message>
    <message>
        <source>TimeToFull</source>
        <translation type="vanished">充满时间</translation>
    </message>
    <message>
        <source>TimeToEmpty</source>
        <translation type="vanished">放完时间</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="494"/>
        <source>Percentage</source>
        <translation>百分比</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="499"/>
        <source>Capacity</source>
        <translation>容量</translation>
    </message>
    <message>
        <source>Power Statistics</source>
        <translation type="vanished">电源统计</translation>
    </message>
    <message>
        <source>help</source>
        <translation type="vanished">帮助</translation>
    </message>
    <message>
        <source>exit</source>
        <translation type="vanished">退出</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation type="vanished">统计</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1210"/>
        <location filename="ukpm-widget.cpp" line="1373"/>
        <source>graphic type:</source>
        <translation>图表类型:</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1213"/>
        <source>charge</source>
        <translation>充电图</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1213"/>
        <source>charge-accurency</source>
        <translation>充电精度</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1213"/>
        <source>discharge</source>
        <translation>放电图</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1213"/>
        <source>discharge-accurency</source>
        <translation>放电精度</translation>
    </message>
    <message>
        <source>spline</source>
        <translation type="vanished">使用平滑线</translation>
    </message>
    <message>
        <source>show datapoint</source>
        <translation type="vanished">显示数据点</translation>
    </message>
    <message>
        <source>no data to show.</source>
        <translation type="vanished">没有可以显示的数据。</translation>
    </message>
    <message>
        <source>History</source>
        <translation type="vanished">历史</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1375"/>
        <source>time span:</source>
        <translation>时间范围:</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1380"/>
        <source>rate</source>
        <translation>功率</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1380"/>
        <source>energy</source>
        <translation>电量</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1380"/>
        <source>charge-time</source>
        <translation>充电时间</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1380"/>
        <source>discharge-time</source>
        <translation>放电时间</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1383"/>
        <source>ten minutes</source>
        <translation>10 分钟</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1383"/>
        <source>two hours</source>
        <translation>2 小时</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1383"/>
        <source>six hours</source>
        <translation>6 小时</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1383"/>
        <source>one day</source>
        <translation>一天</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1383"/>
        <source>one week</source>
        <translation>一周</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1439"/>
        <source>elapsed time</source>
        <translation>已过去时间</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="711"/>
        <location filename="ukpm-widget.cpp" line="800"/>
        <source>adjust factor</source>
        <translation>修正因素</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="213"/>
        <location filename="ukpm-widget.cpp" line="319"/>
        <location filename="ukpm-widget.cpp" line="1940"/>
        <source>PendingCharge</source>
        <translation>待充电</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="216"/>
        <location filename="ukpm-widget.cpp" line="322"/>
        <location filename="ukpm-widget.cpp" line="1943"/>
        <source>PendingDischarge</source>
        <translation>待放电</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="413"/>
        <source>Attribute</source>
        <translation>属性</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="413"/>
        <source>Value</source>
        <translation>值</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="425"/>
        <source>Serial number</source>
        <translation>序列号</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="427"/>
        <source>Supply</source>
        <translation>供应</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="436"/>
        <source>Refreshed</source>
        <translation>已刷新</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="444"/>
        <source>Present</source>
        <translation>当前电池</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="450"/>
        <source>Rechargeable</source>
        <translation>可充电</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="464"/>
        <source>Energy when full</source>
        <translation>满时能量</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="465"/>
        <source>Energy (design)</source>
        <translation>能量(设计)</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="481"/>
        <source>Time to full</source>
        <translation>充满时间</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="485"/>
        <source>Time to empty</source>
        <translation>放完时间</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="521"/>
        <source>history</source>
        <translation>历史</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="532"/>
        <source>statistics</source>
        <translation>统计</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="714"/>
        <location filename="ukpm-widget.cpp" line="757"/>
        <location filename="ukpm-widget.cpp" line="803"/>
        <location filename="ukpm-widget.cpp" line="846"/>
        <source>battery power</source>
        <translation>电池电量</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="754"/>
        <location filename="ukpm-widget.cpp" line="840"/>
        <source>Predict Accurency</source>
        <translation>预测准确度</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1219"/>
        <location filename="ukpm-widget.cpp" line="1392"/>
        <source>show line</source>
        <translation>显示曲线</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1220"/>
        <location filename="ukpm-widget.cpp" line="1393"/>
        <source>show data points</source>
        <translation>显示数据点</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1345"/>
        <source>detail</source>
        <translation>详细</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="470"/>
        <location filename="ukpm-widget.cpp" line="978"/>
        <source>Rate</source>
        <translation>功率</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="995"/>
        <source>Charge</source>
        <translation>电量</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1016"/>
        <location filename="ukpm-widget.cpp" line="1059"/>
        <source>Predict Time</source>
        <translation>预计时间</translation>
    </message>
    <message>
        <location filename="ukpm-widget.h" line="124"/>
        <source>s</source>
        <translation>秒</translation>
    </message>
    <message>
        <location filename="ukpm-widget.h" line="126"/>
        <source>m</source>
        <translation>分钟</translation>
    </message>
    <message>
        <location filename="ukpm-widget.h" line="128"/>
        <source>h</source>
        <translation>小时</translation>
    </message>
    <message>
        <location filename="ukpm-widget.h" line="133"/>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="ukpm-widget.h" line="133"/>
        <source>no</source>
        <translation>不</translation>
    </message>
    <message>
        <source>line-power</source>
        <translation type="vanished">交流电源适配器</translation>
    </message>
    <message>
        <source>battery</source>
        <translation type="vanished">笔记本电池</translation>
    </message>
    <message>
        <source>ac-adapter</source>
        <translation type="vanished">交流电源适配器</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source> s</source>
        <translation type="obsolete">秒</translation>
    </message>
    <message>
        <source> m</source>
        <translation type="obsolete">分钟</translation>
    </message>
    <message>
        <source> h</source>
        <translation type="obsolete">小时</translation>
    </message>
    <message>
        <source>Charging</source>
        <translation type="obsolete">充电中</translation>
    </message>
    <message>
        <source>Discharging</source>
        <translation type="obsolete">放电中</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation type="obsolete">空</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation type="obsolete">充满</translation>
    </message>
    <message>
        <source>from full battery %1(%2)</source>
        <translation type="obsolete">离充满电还有%1(%2)</translation>
    </message>
    <message>
        <source>from empty battery %1(%2)</source>
        <translation type="obsolete">电池剩余时间 %1(%2)</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">是</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">不</translation>
    </message>
    <message>
        <source>DC Suply</source>
        <translation type="obsolete">交流电源适配器</translation>
    </message>
    <message>
        <source>Battery Suply</source>
        <translation type="obsolete">电池</translation>
    </message>
    <message>
        <source>Detail</source>
        <translation type="obsolete">详细</translation>
    </message>
    <message>
        <source>attribute</source>
        <translation type="obsolete">属性</translation>
    </message>
    <message>
        <source>value</source>
        <translation type="obsolete">值</translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="obsolete">设备</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="obsolete">类型</translation>
    </message>
    <message>
        <source>PowerSupply</source>
        <translation type="obsolete">电源</translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="obsolete">在线</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation type="obsolete">生产商</translation>
    </message>
    <message>
        <source>Model</source>
        <translation type="obsolete">型号</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="obsolete">刷新</translation>
    </message>
    <message>
        <source>IsPresent</source>
        <translation type="obsolete">存在</translation>
    </message>
    <message>
        <source>IsRechargeable</source>
        <translation type="obsolete">可充电</translation>
    </message>
    <message>
        <source>State</source>
        <translation type="obsolete">状态</translation>
    </message>
    <message>
        <source>Energy</source>
        <translation type="obsolete">能量</translation>
    </message>
    <message>
        <source>EnergyFull</source>
        <translation type="obsolete">满时能量</translation>
    </message>
    <message>
        <source>EnergyFullDesign</source>
        <translation type="obsolete">设计满时能量</translation>
    </message>
    <message>
        <source>EnergyRate</source>
        <translation type="obsolete">功率</translation>
    </message>
    <message>
        <source>Voltage</source>
        <translation type="obsolete">电压</translation>
    </message>
    <message>
        <source>TimeToFull</source>
        <translation type="obsolete">充满时间</translation>
    </message>
    <message>
        <source>TimeToEmpty</source>
        <translation type="obsolete">放完时间</translation>
    </message>
    <message>
        <source>Percentage</source>
        <translation type="obsolete">百分比</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation type="obsolete">容量</translation>
    </message>
    <message>
        <source>help</source>
        <translation type="obsolete">帮助</translation>
    </message>
    <message>
        <source>exit</source>
        <translation type="obsolete">退出</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation type="obsolete">统计</translation>
    </message>
    <message>
        <source>graphic type:</source>
        <translation type="obsolete">类型:</translation>
    </message>
    <message>
        <source>charge</source>
        <translation type="obsolete">充电</translation>
    </message>
    <message>
        <source>charge-accurency</source>
        <translation type="obsolete">充电精度</translation>
    </message>
    <message>
        <source>discharge</source>
        <translation type="obsolete">放电</translation>
    </message>
    <message>
        <source>discharge-accurency</source>
        <translation type="obsolete">放电精度</translation>
    </message>
    <message>
        <source>spline</source>
        <translation type="obsolete">平滑曲线</translation>
    </message>
    <message>
        <source>show datapoint</source>
        <translation type="obsolete">显示数据</translation>
    </message>
    <message>
        <source>History</source>
        <translation type="obsolete">历史</translation>
    </message>
    <message>
        <source>time span:</source>
        <translation type="obsolete">时间范围:</translation>
    </message>
    <message>
        <source>rate</source>
        <translation type="obsolete">功率</translation>
    </message>
    <message>
        <source>energy</source>
        <translation type="obsolete">电量</translation>
    </message>
    <message>
        <source>charge-time</source>
        <translation type="obsolete">充电时间</translation>
    </message>
    <message>
        <source>discharge-time</source>
        <translation type="obsolete">放电时间</translation>
    </message>
    <message>
        <source>ten minutes</source>
        <translation type="obsolete">10 分钟</translation>
    </message>
    <message>
        <source>two hours</source>
        <translation type="obsolete">2 小时</translation>
    </message>
    <message>
        <source>six hours</source>
        <translation type="obsolete">6 小时</translation>
    </message>
    <message>
        <source>one day</source>
        <translation type="obsolete">一天</translation>
    </message>
    <message>
        <source>one week</source>
        <translation type="obsolete">一周</translation>
    </message>
    <message>
        <source>Notebook battery</source>
        <translation type="vanished">笔记本电池</translation>
    </message>
    <message>
        <source>available energy</source>
        <translation type="vanished">可用电源</translation>
    </message>
    <message>
        <source>charged full</source>
        <translation type="vanished">电池已充满</translation>
    </message>
    <message>
        <source>Power Statistics</source>
        <translation type="vanished">电源统计</translation>
    </message>
    <message>
        <source>Power attributes</source>
        <translation type="vanished">电源属性</translation>
    </message>
    <message>
        <source>Power Select</source>
        <translation type="vanished">电源选项</translation>
    </message>
    <message>
        <source>AC Adapter</source>
        <translation type="obsolete">交流电源适配器</translation>
    </message>
    <message>
        <source>ac-adapter</source>
        <translation type="obsolete">交流电源适配器</translation>
    </message>
    <message>
        <source>other</source>
        <translation type="obsolete">未知</translation>
    </message>
</context>
</TS>
